camelot.camelot.types.VirtualAddress

Package camelot :: Package camelot :: Package types :: Class VirtualAddress |
[hide private]
[frames] | no frames]

# Class VirtualAddress

source code

Sqlalchemy type to store virtual addresses : eg, phone number, e-mail address, ...

This column type accepts and returns tuples of strings, the first string is the virtual_address_type, and the second the address itself:

eg: ('mail','project-camelot@conceptive.be') is stored as mail://project-camelot@conceptive.be

Instance Methods | [hide private]
bind_processor(self, dialect) | source code
result_processor(self, dialect) | source code

Class Variables | [hide private]
| impl = `types.Unicode`
| virtual_address_types = `['phone', 'fax', 'mobile', 'email', 'i`...``

Class Variable Details | [hide private]

  ### virtual_address_types Value:
      ['phone', 'fax', 'mobile', 'email', 'im', 'pager',]